"""KiCad python module for interpreting generic netlists which can be used to generate bills of materials."""
# This file is generated automatically from metadata
# File edits may be overwritten!
from kicad_netlist_reader.__about__ import (
    __author__,
    __copyright__,
    __email__,
    __license__,
    __description__,
    __url__,
    __version__)

from .kicad_netlist_reader import netlist, comp, xmlElement, libpart
