"""KiCad python module for interpreting generic netlists which can be used to generate bills of materials."""
# This file is generated automatically from metadata
# File edits may be overwritten!
from setuptools import setup


if __name__ == '__main__':
    setup()
